@@ -20,6 +20,7 @@ Interface for Dynamips virtual Cisco 1700 instances module ("c1700")
 http://github.com/GNS3/dynamips/blob/master/README.hypervisor#L428
 """
 
+import asyncio
 from .router import Router
 from ..adapters.c1700_mb_1fe import C1700_MB_1FE
 from ..adapters.c1700_mb_wic1 import C1700_MB_WIC1
@@ -29,65 +30,53 @@ log = logging.getLogger(__name__)
 
 
 class C1700(Router):
+
     """
     Dynamips c1700 router.
 
-    :param hypervisor: Dynamips hypervisor instance
-    :param name: name for this router
-    :param router_id: router instance ID
+    :param name: The name of this router
+    :param vm_id: Router instance identifier
+    :param project: Project instance
+    :param manager: Parent VM Manager
+    :param dynamips_id: ID to use with Dynamips
+    :param console: console port
+    :param aux: auxiliary console port
     :param chassis: chassis for this router:
     1720, 1721, 1750, 1751 or 1760 (default = 1720).
     1710 is not supported.
     """
 
-    def __init__(self, hypervisor, name, router_id=None, chassis="1720"):
-        Router.__init__(self, hypervisor, name, router_id, platform="c1700")
+    def __init__(self, name, vm_id, project, manager, dynamips_id, console=None, aux=None, chassis="1720"):
 
-        # Set default values for this platform
-        self._ram = 128
+        super().__init__(name, vm_id, project, manager, dynamips_id, console, aux, platform="c1700")
+
+        # Set default values for this platform (must be the same as Dynamips)
+        self._ram = 64
         self._nvram = 32
         self._disk0 = 0
         self._disk1 = 0
         self._chassis = chassis
         self._iomem = 15  # percentage
         self._clock_divisor = 8
-        self._sparsemem = False
+        self._sparsemem = False  # never activate sparsemem for c1700 (unstable)
 
-        if chassis != "1720":
-            self.chassis = chassis
+    def __json__(self):
 
-        self._setup_chassis()
-
-    def defaults(self):
-        """
-        Returns all the default attribute values for this platform.
-
-        :returns: default values (dictionary)
-        """
-
-        router_defaults = Router.defaults(self)
-
-        platform_defaults = {"ram": self._ram,
-                             "nvram": self._nvram,
-                             "disk0": self._disk0,
-                             "disk1": self._disk1,
+        c1700_router_info = {"iomem": self._iomem,
                              "chassis": self._chassis,
-                             "iomem": self._iomem,
-                             "clock_divisor": self._clock_divisor,
                              "sparsemem": self._sparsemem}
 
-        # update the router defaults with the platform specific defaults
-        router_defaults.update(platform_defaults)
-        return router_defaults
+        router_info = Router.__json__(self)
+        router_info.update(c1700_router_info)
+        return router_info
 
-    def list(self):
-        """
-        Returns all c1700 instances
+    @asyncio.coroutine
+    def create(self):
 
-        :returns: c1700 instance list
-        """
-
-        return self._hypervisor.send("c1700 list")
+        yield from Router.create(self)
+        if self._chassis != "1720":
+            yield from self.set_chassis(self._chassis)
+        self._setup_chassis()
 
     def _setup_chassis(self):
         """
@@ -114,8 +103,8 @@ class C1700(Router):
 
         return self._chassis
 
-    @chassis.setter
-    def chassis(self, chassis):
+    @asyncio.coroutine
+    def set_chassis(self, chassis):
         """
         Sets the chassis.
 
@@ -123,12 +112,11 @@ class C1700(Router):
         1720, 1721, 1750, 1751 or 1760
         """
 
-        self._hypervisor.send("c1700 set_chassis {name} {chassis}".format(name=self._name,
-                                                                          chassis=chassis))
+        yield from self._hypervisor.send('c1700 set_chassis "{name}" {chassis}'.format(name=self._name, chassis=chassis))
 
-        log.info("router {name} [id={id}]: chassis set to {chassis}".format(name=self._name,
-                                                                            id=self._id,
-                                                                            chassis=chassis))
+        log.info('Router "{name}" [{id}]: chassis set to {chassis}'.format(name=self._name,
+                                                                           id=self._id,
+                                                                           chassis=chassis))
 
         self._chassis = chassis
         self._setup_chassis()
@@ -143,19 +131,18 @@ class C1700(Router):
 
         return self._iomem
 
-    @iomem.setter
-    def iomem(self, iomem):
+    @asyncio.coroutine
+    def set_iomem(self, iomem):
         """
         Sets I/O memory size for this router.
 
         :param iomem: I/O memory size
         """
 
-        self._hypervisor.send("c1700 set_iomem {name} {size}".format(name=self._name,
-                                                                     size=iomem))
+        yield from self._hypervisor.send('c1700 set_iomem "{name}" {size}'.format(name=self._name, size=iomem))
 
-        log.info("router {name} [id={id}]: I/O memory updated from {old_iomem}% to {new_iomem}%".format(name=self._name,
-                                                                                                        id=self._id,
-                                                                                                        old_iomem=self._iomem,
-                                                                                                        new_iomem=iomem))
+        log.info('Router "{name}" [{id}]: I/O memory updated from {old_iomem}% to {new_iomem}%'.format(name=self._name,
+                                                                                                       id=self._id,
+                                                                                                       old_iomem=self._iomem,
+                                                                                                       new_iomem=iomem))
         self._iomem = iomem
