@@ -20,6 +20,7 @@ Interface for Dynamips virtual Cisco 2600 instances module ("c2600")
 http://github.com/GNS3/dynamips/blob/master/README.hypervisor#L404
 """
 
+import asyncio
 from .router import Router
 from ..adapters.c2600_mb_1e import C2600_MB_1E
 from ..adapters.c2600_mb_2e import C2600_MB_2E
@@ -31,12 +32,17 @@ log = logging.getLogger(__name__)
 
 
 class C2600(Router):
+
     """
     Dynamips c2600 router.
 
-    :param hypervisor: Dynamips hypervisor instance
-    :param name: name for this router
-    :param router_id: router instance ID
+    :param name: The name of this router
+    :param vm_id: Router instance identifier
+    :param project: Project instance
+    :param manager: Parent VM Manager
+    :param dynamips_id: ID to use with Dynamips
+    :param console: console port
+    :param aux: auxiliary console port
     :param chassis: chassis for this router:
     2610, 2611, 2620, 2621, 2610XM, 2611XM
     2620XM, 2621XM, 2650XM or 2651XM (default = 2610).
@@ -55,54 +61,37 @@ class C2600(Router):
                            "2650XM": C2600_MB_1FE,
                            "2651XM": C2600_MB_2FE}
 
-    def __init__(self, hypervisor, name, router_id=None, chassis="2610"):
-        Router.__init__(self, hypervisor, name, router_id, platform="c2600")
+    def __init__(self, name, vm_id, project, manager, dynamips_id, console=None, aux=None, chassis="2610"):
 
-        # Set default values for this platform
-        self._ram = 128
+        super().__init__(name, vm_id, project, manager, dynamips_id, console, aux, platform="c2600")
+
+        # Set default values for this platform (must be the same as Dynamips)
+        self._ram = 64
         self._nvram = 128
         self._disk0 = 0
         self._disk1 = 0
         self._chassis = chassis
         self._iomem = 15  # percentage
         self._clock_divisor = 8
-        self._sparsemem = False
+        self._sparsemem = False  # never activate sparsemem for c2600 (unstable)
 
-        if chassis != "2610":
-            self.chassis = chassis
+    def __json__(self):
 
-        self._setup_chassis()
-
-    def defaults(self):
-        """
-        Returns all the default attribute values for this platform.
-
-        :returns: default values (dictionary)
-        """
-
-        router_defaults = Router.defaults(self)
-
-        platform_defaults = {"ram": self._ram,
-                             "nvram": self._nvram,
-                             "disk0": self._disk0,
-                             "disk1": self._disk1,
-                             "iomem": self._iomem,
+        c2600_router_info = {"iomem": self._iomem,
                              "chassis": self._chassis,
-                             "clock_divisor": self._clock_divisor,
                              "sparsemem": self._sparsemem}
 
-        # update the router defaults with the platform specific defaults
-        router_defaults.update(platform_defaults)
-        return router_defaults
+        router_info = Router.__json__(self)
+        router_info.update(c2600_router_info)
+        return router_info
 
-    def list(self):
-        """
-        Returns all c2600 instances
+    @asyncio.coroutine
+    def create(self):
 
-        :returns: c2600 instance list
-        """
-
-        return self._hypervisor.send("c2600 list")
+        yield from Router.create(self)
+        if self._chassis != "2610":
+            yield from self.set_chassis(self._chassis)
+        self._setup_chassis()
 
     def _setup_chassis(self):
         """
@@ -123,8 +112,8 @@ class C2600(Router):
 
         return self._chassis
 
-    @chassis.setter
-    def chassis(self, chassis):
+    @asyncio.coroutine
+    def set_chassis(self, chassis):
         """
         Sets the chassis.
 
@@ -133,12 +122,11 @@ class C2600(Router):
         2620XM, 2621XM, 2650XM or 2651XM
         """
 
-        self._hypervisor.send("c2600 set_chassis {name} {chassis}".format(name=self._name,
-                                                                          chassis=chassis))
+        yield from self._hypervisor.send('c2600 set_chassis "{name}" {chassis}'.format(name=self._name, chassis=chassis))
 
-        log.info("router {name} [id={id}]: chassis set to {chassis}".format(name=self._name,
-                                                                            id=self._id,
-                                                                            chassis=chassis))
+        log.info('Router "{name}" [{id}]: chassis set to {chassis}'.format(name=self._name,
+                                                                           id=self._id,
+                                                                           chassis=chassis))
         self._chassis = chassis
         self._setup_chassis()
 
@@ -152,19 +140,18 @@ class C2600(Router):
 
         return self._iomem
 
-    @iomem.setter
-    def iomem(self, iomem):
+    @asyncio.coroutine
+    def set_iomem(self, iomem):
         """
         Sets I/O memory size for this router.
 
         :param iomem: I/O memory size
         """
 
-        self._hypervisor.send("c2600 set_iomem {name} {size}".format(name=self._name,
-                                                                     size=iomem))
+        yield from self._hypervisor.send('c2600 set_iomem "{name}" {size}'.format(name=self._name, size=iomem))
 
-        log.info("router {name} [id={id}]: I/O memory updated from {old_iomem}% to {new_iomem}%".format(name=self._name,
-                                                                                                        id=self._id,
-                                                                                                        old_iomem=self._iomem,
-                                                                                                        new_iomem=iomem))
+        log.info('Router "{name}" [{id}]: I/O memory updated from {old_iomem}% to {new_iomem}%'.format(name=self._name,
+                                                                                                       id=self._id,
+                                                                                                       old_iomem=self._iomem,
+                                                                                                       new_iomem=iomem))
         self._iomem = iomem
