@@ -16,24 +16,12 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-Custom exceptions for VPCS module.
+Custom exceptions for the VPCS module.
 """
 
+from ..vm_error import VMError
 
-class VPCSError(Exception):
 
-    def __init__(self, message, original_exception=None):
+class VPCSError(VMError):
 
-        Exception.__init__(self, message)
-        if isinstance(message, Exception):
-            message = str(message)
-        self._message = message
-        self._original_exception = original_exception
-
-    def __repr__(self):
-
-        return self._message
-
-    def __str__(self):
-
-        return self._message
+    pass
